Django Gears
============

.. image:: https://secure.travis-ci.org/trilan/django-gears.png?branch=develop

Gears_ for Django_.

.. _Gears: http://git.io/gears
.. _Django: https://www.djangoproject.com/
